@@ -1,5 +1,6 @@
 """Module of logging"""
 from typing import ClassVar, List, Optional, TypeVar, Union
+import abc
 import functools
 import os
 import sys
@@ -28,7 +29,45 @@ __all__ = [
 
 T = TypeVar("T")
 
-def trackingFunctionCalls(function: T, logger=logging) -> T:
+class LoggerBase(abc.ABC):
+    @abc.abstractmethod
+    def setLevel(self, *_, **__):
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def debug(self, *_, **__):
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def info(self, *_, **__):
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def warning(self, *_, **__):
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def warn(self, *_, **__):
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def error(self, *_, **__):
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def exception(self, *_, **__):
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def critical(self, *_, **__):
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def log(self, *_, **__):
+        raise NotImplementedError
+
+
+def trackingFunctionCalls(function: T, logger: Union[logging.Logger, LoggerBase] = logging.root) -> T:
     fullName = functionFullName(function)
     if isinstance(function, functools.partial):
         funcArgs = function.args
